
# A Music Recommender System for Constructed Music Evoked Autobiographical Memories - Personal Data
Authors: P. Raingeard de la Bletiere, M. Neerincx, R. Schaefer, C. Oertel
Interactive Intelligence Group, Faculty of Computer Science, Delft
University of Technology
Corresponding author: P. Raingeard de la Bletiere
Contact Information:
p.raibgearddelabletiere@tudelft.nl
Delft University of Technology - Faculty of Computer Science
Van Mourik Broekmanweg 6
2628 XE Delft
The Netherlands

## Related Datasets
The dataset regarding personal data collected during this experiment can be found here: DOI: 10.4121/6d820fc9-efcf-4bc8-9fa1-b575e0264f3f

## General Introduction
This dataset contains data collected during an experiments at Delft University
of Technology, as part of Paul Raingeard de la Bletiere's PhD Thesis project.
It is being made public both to act as supplementary data for publications and the PhD thesis of Paul Raingeard de la Bletiere and in order for other researchers to use this data in their own work.
The data in this data set was collected through a website accessed by participants between August 2024 and December 2024.
This research project was made possible by a grant from the Dutch Research Concil (NWO) (Grant number KICH1.GZ02.20.008). Additional support from Alzheimer Nederland is gratefully acknowledged.

## Purpose of the this experiment
The purpose of this experiment was to test a music recommender system linking music with specific episodic memories chosen by participants, through a discussion with a virtual agent. This specific part of the data relates to the rating of recommendations by participants.

## Transformation of this Data
The qualitative data present in this dataset, originally in Dutch and French, was translated in English using Seamless M4T. It was later checked by french and dutch native speakers for mistakes. 

## Experiment Setting
All tests were performed on a website hosted by TUDelft. Participants had to fill demographic questionnaires, chose a memory, discuss it with the agent and then rate the given recommendations depending on several song and individual characteristics. Finally, they had to make a ranking of the songs.

## Description of the data in this data set
The data included in this data set has been organised in 2 files. 

For both of these files you will find the following columns:

- Username is the random pseudonym generated by the website to identify a user
- memory_number is the index of the memory for this specific user (0 if they only provided one memory, 1 if it is the second time they provided a memory).
- language is the original language of the user (dutch or french)

In Final_Translated_Questions_Updated.csv, you will find the rating data filled by participants.

The content of this file depends on the person scenario and place scenario chosen by participants: depending on their answers we utilized people and place cues to personalize recommendations. Here are the corresponding scenarios and their numbers, as precised in columns scenario_place and scenario_people:

For Scenario People:
0: The participant identified a specific person (other than them) that is present in that memory, and linked an artist with this person.
1: The participant identified a specific person (other than them) that is present in that memory, and linked a genre with this person.
2: The participant identified a specific person (other than them) that is present in that memory, but do not link anything with this person.
3: The participant is alone in their memory, and identified an artist they like.
4: The participant is alone in their memory, and identified a genre they like.

For Scenario Place:
0: The participant links an artist to the place in the memory.
1: The participant links a genre to the place in the memory.
2: The participant does not link anything to the place in the memory.

We also did have indexes depending on whether or not mood matching was applied to match the memory mood to the song's mood. This gived the following 4 indexes given in the column Song Index:

- 0 is a recommendation linked to the person in the memory (depending on person scenario), and with mood matching.
- 1 is a recommendation linked to the person in the memory (depending on person scenario), and without mood matching.
- 2 is a recommendation linked to the place in the memory (depending on place scenario), and with mood matching.
- 3 is a recommendation linked to the place in the memory (depending on place scenario), and without mood matching.

The file contains the following columns:

- valence_pre, arousal_pre and dominance_pre are the filled valence, arousal and dominance corresponding to the given memory.
- valence_post, arousal_post and dominance_post are the filled valence, arousal and dominance corresponding to the recommended song by the participant.
- Song Name is the recommended song title
- Song Artist is the recommended song artist
- Song Index is the index of the song corresponding to the condition, as described earlier
- FitValue is the value given by the user from 0 to 100 of how much the song was fitting to represent the memory they chose
- WhyFitValue is the explanation given by the user on why they chose this specific fit value
- KnownStyle is a value given by the user from 0 to 100 corresponding to how well they know the genre of the recommended song 
- KnownSong  is a value given by the user from 0 to 100 corresponding to how well they know the specific recommended song (how often they heard it)
- OtherMemory is a qualitative input by the user indicating if they had any other comment or other memory coming up with the recommended song
- song_index_fake is the order of appearance of the given song for the user, which was randomized
- EraFit,EventFit,PlaceFit,PeopleFit are the values given by the user from 0 to 100 of how much the song was fitting to represent specific elements of the memory they chose
- FactorTempo,FactorValence,FactorArousal,FactorInstruments,FactorLyrics,FactorFamiliarity,FactorGenre,FactorArtist,FactorEra,FactorLikeability are self rated factors (from -50 to +50) of the influence of these characteristics in the user's choice of fit rating.

- Positiveness is the valence given by spotify API for the chosen song
- Energy is the arousal given by spotify API for the chosen song
- Popularity is the popularity given by spotify API for the chosen song
- spotify_id is the spotify ID given by spotify API for the chosen song

- FactorIDontHear,FactorOtherMemoryConnection,FactorWorstBandEver are user added factors to describe their influence (from -50 to +50) of these characteristics in the user's choice of fit rating.

- MusicImportance is a rating from 0 to 100 indicating how much music is important for the user
- AgeGroup is the age group of the user (0: 18-25, 1:40-60, 2:65+)
- place_scenario,person_scenario are the previously described scenarios corresponding to the recommendation

In Final_Last_Questions.csv, you will find details about the final questions filled by participants.

- ranks is the self ranking of song indexes from best to worst (although users had 2 different interpretations of this ranking which was thus not used in out analysis)
- additionalComments corresponds to general comments from users on our system, as well as the specific name of a song that would be the best match for their memory (if they had one)
- memoryImportance corresponds to how much the chosen memory was important to the user (from 1 to 100)
- MoreInformationType corresponds to the answers of users on what should the system know about them to make better recommendations
- MemoryReflect is a rating from 1 to 100 indicating how well the songs could help the user reflect on their memory
- BetterIdeaSong is a rating from 1 to 100 indicating how much listening to this songs could help users get a better idea of what song to link to their memory
- WhichKindofSong is the type of song that the user feels would be best suited for their memory (if they have one in mind)

